@@ -3,9 +3,6 @@
 #include <R_ext/Rdynload.h>
 
 SEXP anyMissing(SEXP);
-SEXP copyEnv(SEXP e1, SEXP e2, SEXP all);
-SEXP listToEnv(SEXP, SEXP);
-SEXP listLen(SEXP);
 SEXP rowQ(SEXP, SEXP);
 SEXP rowMedians(SEXP, SEXP, SEXP, SEXP);
 SEXP rowQuantiles(SEXP, SEXP);
@@ -20,9 +17,6 @@ __declspec(dllexport)
 
     static const R_CallMethodDef R_CallDef[] = {
         {"anyMissing", (DL_FUNC)&anyMissing, 1},
-        {"copyEnv", (DL_FUNC)&copyEnv, 3},
-        {"listToEnv", (DL_FUNC)&listToEnv, 2},
-        {"listLen", (DL_FUNC)&listLen, 1},
         {"rowQ", (DL_FUNC)&rowQ, 2},
         {"rowMedians", (DL_FUNC)&rowMedians, 4},
         {"unsafe_set_slot", (DL_FUNC)&unsafe_set_slot, 3},
